@@ -1,5 +1,5 @@
 """
-Version 0.2.1 (in development)
+Version 0.3.0 (in development)
 ==============================
 
 A Python implementation of the Unity Engine
@@ -24,7 +24,7 @@ This is the output with debugging::
     FreeGLUT doesn't work, trying GLFW
     GLFW doesn't work, trying Pygame
     Using window provider Pygame
-    Loaded PyUnity version 0.2.1
+    Loaded PyUnity version 0.3.0
 
 If debugging is off, there is no output:
 
@@ -107,22 +107,34 @@ To run an example, import it like so:
     FreeGLUT doesn't work, trying GLFW
     GLFW doesn't work, trying Pygame
     Using window provider Pygame
-    Loaded PyUnity version 0.2.1
+    Loaded PyUnity version 0.3.0
     >>> main()
 
-Or from the command line:
+Or from the command line::
 
     > python -m pyunity 1
 
 The ``1`` just means to load example 1, and there
 are 8 examples. To load all examples one by
 one, do not specify a number. If you want to
-contribute an example, then please create a
-new pull request.
+contribute an example, then please
+create a new pull request.
 
 """
 
-__version__ = "0.2.1"
+from .audio import *
+from .core import *
+from . import loader  # lgtm[py/import-own-module]
+from . import input as Input  # lgtm[py/import-own-module]
+from .input import KeyCode
+from .physics import *
+from .errors import *
+from .scene import SceneManager
+from .quaternion import Quaternion
+from .vector3 import Vector3
+from .meshes import Mesh
+import os
+__version__ = "0.3.0"
 __copyright__ = "Copyright 2020 Ray Chen"
 __email__ = "tankimarshal2@gmail.com"
 __license__ = "MIT License"
@@ -130,29 +142,14 @@ __summary__ = "A Python implementation of the Unity Engine that supports differe
 __title__ = "pyunity"
 __uri__ = "https://pyunity.readthedocs.io/en/latest/"
 
-import os
-from .audio import *
-from .core import *
-from .vector3 import *
-from .quaternion import *
-from .scene import SceneManager
-from .physics import *
-from . import loader
-
-def timer(func):
-    """
-    Use this decorator to print how long
-    a function takes.
-
-    """
-    def wrapper(*args, **kwargs):
-        start = time()
-        func(*args, **kwargs)
-        print(round(time() - start, 3))
-    return wrapper
+from . import audio, core, physics, errors
+__all__ = ["__version__", "Vector3", "Quaternion",
+           "SceneManager", "Mesh", "loader",
+           "Input", "KeyCode"]
+__all__.extend(audio.__all__)
+__all__.extend(core.__all__)
+__all__.extend(physics.__all__)
+__all__.extend(errors.__all__)
 
 if os.environ["PYUNITY_DEBUG_MODE"] == "1":
     print("Loaded PyUnity version %s" % __version__)
-
-if os.environ["PYUNITY_INTERACTIVE"] == "1": del window, gl
-del core, scene, math, errors, operator, vector3, quaternion, physics, os
\ No newline at end of file
