@@ -17,12 +17,14 @@ example_list = [
 ]
 
 def show():
-    if len(sys.argv) == 1: num = 0
-    else: num = int(sys.argv[1])
+    if len(sys.argv) == 1:
+        num = 0
+    else:
+        num = int(sys.argv[1])
     if not num:
         for index, example in enumerate(example_list):
             print("\nExample", index + 1)
             example.main()
             SceneManager.RemoveScene(SceneManager.GetSceneByName("Scene"))
     else:
-        example_list[num - 1].main()
\ No newline at end of file
+        example_list[num - 1].main()
